@@ -32,7 +32,7 @@ bool zmDbConnected = false;
 
 bool zmDbConnect() {
   // For some reason having these lines causes memory corruption and crashing on newer debian/ubuntu
-	// But they really need to be here in order to prevent a double open of mysql
+  // But they really need to be here in order to prevent a double open of mysql
   if (zmDbConnected)  {
     //Warning("Calling zmDbConnect when already connected");
     return true;
@@ -52,11 +52,11 @@ bool zmDbConnect() {
   std::string::size_type colonIndex = staticConfig.DB_HOST.find(":");
   if ( colonIndex == std::string::npos ) {
     if ( !mysql_real_connect(
-          &dbconn,
-          staticConfig.DB_HOST.c_str(),
-          staticConfig.DB_USER.c_str(),
-          staticConfig.DB_PASS.c_str(),
-          nullptr, 0, nullptr, 0) ) {
+           &dbconn,
+           staticConfig.DB_HOST.c_str(),
+           staticConfig.DB_USER.c_str(),
+           staticConfig.DB_PASS.c_str(),
+           nullptr, 0, nullptr, 0) ) {
       Error("Can't connect to server: %s", mysql_error(&dbconn));
       mysql_close(&dbconn);
       return false;
@@ -66,24 +66,24 @@ bool zmDbConnect() {
     std::string dbPortOrSocket = staticConfig.DB_HOST.substr(colonIndex+1);
     if ( dbPortOrSocket[0] == '/' ) {
       if ( !mysql_real_connect(
-            &dbconn,
-            nullptr,
-            staticConfig.DB_USER.c_str(),
-            staticConfig.DB_PASS.c_str(),
-            nullptr, 0, dbPortOrSocket.c_str(), 0) ) {
+             &dbconn,
+             nullptr,
+             staticConfig.DB_USER.c_str(),
+             staticConfig.DB_PASS.c_str(),
+             nullptr, 0, dbPortOrSocket.c_str(), 0) ) {
         Error("Can't connect to server: %s", mysql_error(&dbconn));
         mysql_close(&dbconn);
         return false;
       }
     } else {
       if ( !mysql_real_connect(
-            &dbconn,
-            dbHost.c_str(),
-            staticConfig.DB_USER.c_str(),
-            staticConfig.DB_PASS.c_str(),
-            nullptr,
-            atoi(dbPortOrSocket.c_str()),
-            nullptr, 0) ) {
+             &dbconn,
+             dbHost.c_str(),
+             staticConfig.DB_USER.c_str(),
+             staticConfig.DB_PASS.c_str(),
+             nullptr,
+             atoi(dbPortOrSocket.c_str()),
+             nullptr, 0) ) {
         Error("Can't connect to server: %s", mysql_error(&dbconn));
         mysql_close(&dbconn);
         return false;
@@ -130,39 +130,35 @@ void zmDbClose() {
   }
 }
 
-MYSQL_RES * zmDbFetch(const char * query) {
+MYSQL_RES *zmDbFetch(const std::string &query) {
   std::lock_guard<std::mutex> lck(db_mutex);
   if (!zmDbConnected && !zmDbConnect()) {
     Error("Not connected.");
     return nullptr;
   }
 
-  int rc = mysql_query(&dbconn, query);
 
+  Debug(3, "Doing Fetch %s", query.c_str());
+  int rc = mysql_query(&dbconn, query.c_str());
   if (rc) {
-    Debug(1, "Can't run query: %s rc:%d, reason:%s", query, rc, mysql_error(&dbconn));
-    if (mysql_ping(&dbconn)) {
-      zmDbConnected = false;
-      if (zmDbConnect()) {
-        Debug(1, "Reconnected to db...");
-        rc = mysql_query(&dbconn, query);
-      } else {
-        Debug(1, "Failed to reconnect to db");
-      }
+    std::string reason = mysql_error(&dbconn); // store for later because it will get clobbered by second attempt
+    Debug(1, "Can't run query: %s rc:%d, reason:%s", query.c_str(), rc, reason.c_str());
+    if (mysql_ping(&dbconn) and zmDbReconnect()) {
+      rc = mysql_query(&dbconn, query.c_str());
+    }
+    if (rc) {
+      Error("Can't run query: %s rc:%d, reason:%s", query.c_str(), rc, reason.c_str());
+      return nullptr;
     }
-  }
-  if (rc) {
-    Error("Can't run query: %s rc:%d, reason:%s", query, rc, mysql_error(&dbconn));
-    return nullptr;
   }
   MYSQL_RES *result = mysql_store_result(&dbconn);
   if (!result) {
-    Error("Can't use query result: %s for query %s", mysql_error(&dbconn), query);
+    Error("Can't use query result: %s for query %s", mysql_error(&dbconn), query.c_str());
   }
   return result;
-} // end MYSQL_RES * zmDbFetch(const char * query);
+}
 
-zmDbRow *zmDbFetchOne(const char *query) {
+zmDbRow *zmDbFetchOne(const std::string &query) {
   zmDbRow *row = new zmDbRow();
   if (row->fetch(query)) {
     return row;
@@ -171,13 +167,13 @@ zmDbRow *zmDbFetchOne(const char *query) {
   return nullptr;
 }
 
-MYSQL_RES *zmDbRow::fetch(const char *query) {
+MYSQL_RES *zmDbRow::fetch(const std::string &query) {
   result_set = zmDbFetch(query);
   if (!result_set) return result_set;
 
   int n_rows = mysql_num_rows(result_set);
-  if (n_rows != 1) {
-    Error("Bogus number of lines return from query, %d returned for query %s.", n_rows, query);
+  if (n_rows > 1) {
+    Error("Bogus number of lines return from query, %d returned for query %s.", n_rows, query.c_str());
     mysql_free_result(result_set);
     result_set = nullptr;
     return result_set;
@@ -187,14 +183,17 @@ MYSQL_RES *zmDbRow::fetch(const char *query) {
   if (!row) {
     mysql_free_result(result_set);
     result_set = nullptr;
-    Error("Error getting row from query %s. Error is %s", query, mysql_error(&dbconn));
-  } else {
-    Debug(5, "Success");
+    Error("Error getting row from query %s. Error is %s", query.c_str(), mysql_error(&dbconn));
   }
   return result_set;
 }
 
-int zmDbDo(const char *query) {
+/* performs SQL queries.  Will repeat if error is LOCK_WAIT_TIMEOUT
+ * We assume that in general our SQL is properly formed, so errors will
+ * be due to external factors.
+ */
+
+int zmDbDo(const std::string &query) {
   std::lock_guard<std::mutex> lck(db_mutex);
   if (!zmDbConnected and !zmDbConnect())
     return 0;
@@ -203,9 +202,9 @@ int zmDbDo(const char *query) {
   Logger::Level oldLevel = logger->databaseLevel();
   logger->databaseLevel(Logger::NOLOG);
 
-  while ((rc = mysql_query(&dbconn, query)) and !zm_terminate) {
+  while ((rc = mysql_query(&dbconn, query.c_str())) and !zm_terminate) {
     std::string reason = mysql_error(&dbconn);
-    Debug(1, "Failed running sql query %s, thread_id: %lu, %d %s", query, db_thread_id, rc, reason.c_str());
+    Debug(1, "Failed running sql query %s, thread_id: %lu, %d %s", query.c_str(), db_thread_id, rc, reason.c_str());
 
     if (mysql_ping(&dbconn)) {
       // Was a connection error
@@ -216,53 +215,55 @@ int zmDbDo(const char *query) {
       if (zm_terminate) return 0;
     } else {
       // Not a connection error
-      Error("Can't run query %s: %d %s", query, rc, reason.c_str());
+      Error("Can't run query %s: %d %s", query.c_str(), rc, reason.c_str());
       if (mysql_errno(&dbconn) != ER_LOCK_WAIT_TIMEOUT) {
         return rc;
       }
-    } // end if connected
+    } // end if !connected
   }
 
-  Debug(1, "Success running sql query %s, thread_id: %lu", query, db_thread_id);
+  Debug(1, "Success running sql query %s, thread_id: %lu", query.c_str(), db_thread_id);
   logger->databaseLevel(oldLevel);
   return 1;
 }
 
-int zmDbDoInsert(const char *query) {
+int zmDbDoInsert(const std::string &query) {
   std::lock_guard<std::mutex> lck(db_mutex);
+  if (!zmDbConnected and !zmDbConnect())
+    return 0;
   int rc;
-  while ( (rc = mysql_query(&dbconn, query)) and !zm_terminate) {
+  while ((rc = mysql_query(&dbconn, query.c_str())) and !zm_terminate) {
+    std::string reason = mysql_error(&dbconn);
     if (mysql_ping(&dbconn)) {
-      zmDbConnected = false;
-      zmDbConnect();
-    }
-    if (zmDbConnected) {
-      Error("Can't run query %s: %s", query, mysql_error(&dbconn));
-      if ( (mysql_errno(&dbconn) != ER_LOCK_WAIT_TIMEOUT) )
+      if (!zmDbReconnect()) sleep(1);
+    } else {
+      Error("Can't run query %s: %d %s", query.c_str(), rc, reason.c_str());
+      if ((mysql_errno(&dbconn) != ER_LOCK_WAIT_TIMEOUT))
         return 0;
     }
   }
+  // Might not be an int... FIXME
   int id = mysql_insert_id(&dbconn);
-  Debug(2, "Success running sql insert %s. Resulting id is %d", query, id);
+  Debug(2, "Success running sql insert %s. Resulting id is %d", query.c_str(), id);
   return id;
 }
 
-int zmDbDoUpdate(const char *query) {
+int zmDbDoUpdate(const std::string &query) {
   std::lock_guard<std::mutex> lck(db_mutex);
+  if (!zmDbConnected and !zmDbConnect())
+    return 0;
   int rc;
-  while ( (rc = mysql_query(&dbconn, query)) and !zm_terminate) {
+  while ( (rc = mysql_query(&dbconn, query.c_str())) and !zm_terminate) {
     if (mysql_ping(&dbconn)) {
-      zmDbConnected = false;
-      zmDbConnect();
-    }
-    if (zmDbConnected) {
-      Error("Can't run query %s: %s", query, mysql_error(&dbconn));
+      if (!zmDbReconnect()) sleep(1);
+    } else {
+      Error("Can't run query %s: %s", query.c_str(), mysql_error(&dbconn));
       if ( (mysql_errno(&dbconn) != ER_LOCK_WAIT_TIMEOUT) )
         return -rc;
     }
   }
   int affected = mysql_affected_rows(&dbconn);
-  Debug(2, "Success running sql update %s. Rows modified %d", query, affected);
+  Debug(2, "Success running sql update %s. Rows modified %d", query.c_str(), affected);
   return affected;
 }
 
@@ -275,8 +276,7 @@ zmDbRow::~zmDbRow() {
 }
 
 zmDbQueue::zmDbQueue() :
-  mTerminate(false)
-{
+  mTerminate(false) {
   mThread = std::thread(&zmDbQueue::process, this);
 }
 
@@ -287,6 +287,7 @@ zmDbQueue::~zmDbQueue() {
 void zmDbQueue::stop() {
   {
     std::unique_lock<std::mutex> lock(mMutex);
+
     mTerminate = true;
   }
   mCondition.notify_all();
@@ -302,12 +303,19 @@ void zmDbQueue::process() {
       mCondition.wait(lock);
     }
     while (!mQueue.empty()) {
+      if (mQueue.size() > 40) {
+        Logger *log = Logger::fetch();
+        Logger::Level db_level = log->databaseLevel();
+        log->databaseLevel(Logger::NOLOG);
+        Warning("db queue size has grown larger %zu than 40 entries", mQueue.size());
+        log->databaseLevel(db_level);
+      }
       std::string sql = mQueue.front();
       mQueue.pop();
       // My idea for leaving the locking around each sql statement is to allow
       // other db writers to get a chance
       lock.unlock();
-      zmDbDo(sql.c_str());
+      zmDbDo(sql);
       lock.lock();
     }
   }
@@ -318,8 +326,8 @@ void zmDbQueue::push(std::string &&sql) {
     std::unique_lock<std::mutex> lock(mMutex);
     if (mTerminate) return;
     mQueue.push(std::move(sql));
+    mCondition.notify_all();
   }
-  mCondition.notify_all();
 }
 
 std::string zmDbEscapeString(const std::string& to_escape) {
