@@ -160,7 +160,7 @@ Event::Event(
 }
 
 int Event::OpenJpegCodec(const Image *image) {
-  av_frame_ptr frame(zm_av_frame_alloc());
+  av_frame_ptr frame(av_frame_alloc());
   image->PopulateFrame(frame.get());
   return OpenJpegCodec(frame.get());
 }
@@ -202,14 +202,14 @@ int Event::OpenJpegCodec(AVFrame *frame) {
     mJpegCodecContext->sw_pix_fmt = chosen_codec_data->sw_pix_fmt;
 
     // Should be able to just set quality with the q setting.  Need to convert the old quality to 2-31
-    int quality = config.jpeg_file_quality;
+    int quality = libjpeg_to_ffmpeg_qv(config.jpeg_file_quality);
 
       //(alarm_frame && (config.jpeg_alarm_file_quality > config.jpeg_file_quality)) ?
       //config.jpeg_alarm_file_quality : 0;   // quality to use, zero is default
-    mJpegCodecContext->qcompress = quality/100.0; // 0-1
-    mJpegCodecContext->qmax = 1;
-    mJpegCodecContext->qmin = 1; //quality/100.0; // 0-1
-    mJpegCodecContext->global_quality = quality/100.0; // 0-1
+    //mJpegCodecContext->qcompress = quality/100.0; // 0-1
+    //mJpegCodecContext->qmax = 1;
+    //mJpegCodecContext->qmin = 1; //quality/100.0; // 0-1
+    mJpegCodecContext->global_quality = quality;//100.0; // 0-1
 
     Debug(1, "Setting pix fmt to %d %s, sw_pix_fmt %d %s", 
         chosen_codec_data->sw_pix_fmt, av_get_pix_fmt_name(chosen_codec_data->sw_pix_fmt),
@@ -263,7 +263,7 @@ int Event::OpenJpegCodec(AVFrame *frame) {
     }
   }
 #if 1
-  output_frame = av_frame_ptr{zm_av_frame_alloc()}; // The assignment here will destruct any previous allocation
+  output_frame = av_frame_ptr{av_frame_alloc()}; // The assignment here will destruct any previous allocation
   output_frame->width  = mJpegCodecContext->width;
   output_frame->height = mJpegCodecContext->height;
   output_frame->format = AV_PIX_FMT_YUVJ420P;
@@ -400,8 +400,10 @@ bool Event::WriteJpeg(AVFrame *in_frame, const std::string &filename) {
   if (!mJpegCodecContext) return false;
 
   int raw_fd = open(filename.c_str(), O_WRONLY | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
-  if (raw_fd < 0)
+  if (raw_fd < 0) {
+    Error("Fail to open %s: %s", filename.c_str(), strerror(raw_fd));
     return false;
+  }
   FILE *outfile = fdopen(raw_fd, "wb");
   if (outfile == nullptr) {
     close(raw_fd);
@@ -419,7 +421,7 @@ bool Event::WriteJpeg(AVFrame *in_frame, const std::string &filename) {
       );
 
 #if 0
-  av_frame_ptr out_frame = av_frame_ptr{zm_av_frame_alloc()};
+  av_frame_ptr out_frame = av_frame_ptr{av_frame_alloc()};
   out_frame->width  = mJpegCodecContext->width;
   out_frame->height = mJpegCodecContext->height;
   out_frame->format = AV_PIX_FMT_YUVJ420P;
@@ -700,82 +702,78 @@ void Event::AddFrame(const std::shared_ptr<ZMPacket>&packet) {
   if (score < 0) score = 0;
   tot_score += score;
 
-  if (packet->image) {
-    if (save_jpegs & 1) {
-      std::string event_file = stringtf(staticConfig.capture_file_format.c_str(), path.c_str(), frames);
-      Debug(1, "Writing capture frame %d to %s", frames, event_file.c_str());
-      if (
-          (packet->ai_frame and WriteJpeg(packet->ai_frame.get(), event_file.c_str()))
-          or
-          (packet->in_frame and WriteJpeg(packet->in_frame.get(), event_file.c_str()))
-          or
-          (packet->image and WriteFrameImage(packet->image, packet->timestamp, event_file.c_str()))
-      ) {
+  if (save_jpegs & 1) {
+    std::string event_file = stringtf(staticConfig.capture_file_format.c_str(), path.c_str(), frames);
+    Debug(1, "Writing capture frame %d to %s", frames, event_file.c_str());
+    if (
+        (packet->ai_frame and WriteJpeg(packet->ai_frame.get(), event_file.c_str()))
+        or
+        (packet->in_frame and WriteJpeg(packet->in_frame.get(), event_file.c_str()))
+        or
+        (packet->image and WriteFrameImage(packet->image, packet->timestamp, event_file.c_str()))
+       ) {
       Debug(1, "Wrote capture frame %d to %s", frames, event_file.c_str());
-        // Success
-      } else {
-        Error("Failed to write frame image");
-      }
-    }  // end if save_jpegs
+      // Success
+    } else {
+      Error("Failed to write frame image");
+    }
+  }  // end if save_jpegs
 
-    Debug(1, "frames %d, score %d max_score %d", frames, score, max_score);
-    // If this is the first frame, we should add a thumbnail to the event directory
-    if ((frames == 1) || (score > max_score) || (!snapshot_file_written)) {
-      write_to_db = true; // web ui might show this as thumbnail, so db needs to know about it.
-      Debug(1, "Writing snapshot to %s", snapshot_file.c_str());
-      if (
-          (packet->ai_frame and WriteJpeg(packet->ai_frame.get(), snapshot_file.c_str()))
-          or
-          (packet->in_frame and WriteJpeg(packet->in_frame.get(), snapshot_file.c_str()))
-          or
-          (packet->image and WriteFrameImage(packet->image, packet->timestamp, snapshot_file.c_str()))
-         ) {
-        snapshot_file_written = true;
-      } else {
-        Warning("Fail to write snapshot");
+  Debug(1, "frames %d, score %d max_score %d", frames, score, max_score);
+  // If this is the first frame, we should add a thumbnail to the event directory
+  if ((frames == 1) || (score > max_score) || (!snapshot_file_written)) {
+    write_to_db = true; // web ui might show this as thumbnail, so db needs to know about it.
+    Debug(1, "Writing snapshot to %s", snapshot_file.c_str());
+    if (
+        (packet->ai_frame and WriteJpeg(packet->ai_frame.get(), snapshot_file.c_str()))
+        or
+        (packet->in_frame and WriteJpeg(packet->in_frame.get(), snapshot_file.c_str()))
+        or
+        (packet->image and WriteFrameImage(packet->image, packet->timestamp, snapshot_file.c_str()))
+       ) {
+      snapshot_file_written = true;
+    } else if (packet->ai_frame or packet->in_frame or packet->image) {
+      Warning("Fail to write snapshot");
+    }
+  } else {
+    Debug(1, "Not Writing snapshot because frames %d score %d > max %d", frames, score, max_score);
+  }
+
+  // We are writing an Alarm frame
+  if (frame_type == ALARM) {
+    // The first frame with a score will be the frame that alarmed the event
+    if (!alarm_frame_written) {
+      write_to_db = true; // OD processing will need it, so the db needs to know about it
+      alarm_frame_written = true;
+      Debug(1, "Writing alarm image to %s", alarm_file.c_str());
+      if (packet->ai_frame) {
+        WriteJpeg(packet->ai_frame.get(), alarm_file.c_str());
+      } else if (packet->in_frame) {
+        WriteJpeg(packet->in_frame.get(), alarm_file.c_str());
+      } else if (packet->image) {
+        WriteFrameImage(packet->image, packet->timestamp, alarm_file.c_str());
+      }
+#if 0
+      if (!WriteFrameImage(packet->image, packet->timestamp, alarm_file.c_str())) {
+        Error("Failed to write alarm frame image to %s", alarm_file.c_str());
+      }
+#endif
+    } else {
+      Debug(3, "Not Writing alarm image because alarm frame already written");
+    }
+  } // end if is an alarm frame
+
+  if (save_jpegs & 2) {
+    if (packet->analysis_image) {
+      std::string event_file = stringtf(staticConfig.analyse_file_format.c_str(), path.c_str(), frames);
+      Debug(1, "Writing analysis frame %d to %s", frames, event_file.c_str());
+      if (!WriteFrameImage(packet->analysis_image, packet->timestamp, event_file.c_str(), true)) {
+        Error("Failed to write analysis frame image to %s", event_file.c_str());
       }
     } else {
-      Debug(1, "Not Writing snapshot because frames %d score %d > max %d", frames, score, max_score);
-    }
-
-    // We are writing an Alarm frame
-    if (frame_type == ALARM) {
-      // The first frame with a score will be the frame that alarmed the event
-      if (!alarm_frame_written) {
-        write_to_db = true; // OD processing will need it, so the db needs to know about it
-        alarm_frame_written = true;
-        Debug(1, "Writing alarm image to %s", alarm_file.c_str());
-        if (packet->ai_frame) {
-          WriteJpeg(packet->ai_frame.get(), alarm_file.c_str());
-        } else if (packet->in_frame) {
-          WriteJpeg(packet->in_frame.get(), alarm_file.c_str());
-        } else if (packet->image) {
-          WriteFrameImage(packet->image, packet->timestamp, alarm_file.c_str());
-        }
-#if 0
-        if (!WriteFrameImage(packet->image, packet->timestamp, alarm_file.c_str())) {
-          Error("Failed to write alarm frame image to %s", alarm_file.c_str());
-        }
-#endif
-      } else {
-        Debug(3, "Not Writing alarm image because alarm frame already written");
-      }
-    } // end if is an alarm frame
-
-    if (save_jpegs & 2) {
-      if (packet->analysis_image) {
-        std::string event_file = stringtf(staticConfig.analyse_file_format.c_str(), path.c_str(), frames);
-        Debug(1, "Writing analysis frame %d to %s", frames, event_file.c_str());
-        if (!WriteFrameImage(packet->analysis_image, packet->timestamp, event_file.c_str(), true)) {
-          Error("Failed to write analysis frame image to %s", event_file.c_str());
-        }
-      } else {
-        Debug(1, "Wanted to save analysis frame, but packet has no analysis_image");
-      }  // end if is an alarm frame
-    }  // end if has analysis images turned on
-  } else {
-    Debug(1, "No image");
-  }  // end if has image
+      Debug(1, "Wanted to save analysis frame, but packet has no analysis_image");
+    }  // end if is an alarm frame
+  }  // end if has analysis images turned on
 
   bool db_frame = ( frame_type == BULK )
                   or ( frame_type == ALARM )
