@@ -74,16 +74,16 @@ static CodecData enc_codecs[] = {
   { AV_CODEC_ID_H265, "hevc", "h265_ni_quadra_enc", AV_PIX_FMT_YUV420P, AV_PIX_FMT_NI_QUAD, AV_HWDEVICE_TYPE_NI_QUADRA, "-1", nullptr },
   { AV_CODEC_ID_H265, "hevc", "h265_ni_quadra_enc", AV_PIX_FMT_YUV420P, AV_PIX_FMT_NI_QUAD, AV_HWDEVICE_TYPE_NI_QUADRA, "-1", nullptr },
   { AV_CODEC_ID_H264, "h264", "h264_ni_quadra_enc", AV_PIX_FMT_YUV420P, AV_PIX_FMT_NI_QUAD, AV_HWDEVICE_TYPE_NI_QUADRA, "-1", nullptr },
-  //{ AV_CODEC_ID_MJPEG, "mjpeg", "jpeg_ni_quadra_enc", AV_PIX_FMT_YUVJ420P, AV_PIX_FMT_NI_QUAD, AV_HWDEVICE_TYPE_NI_QUADRA, "-1", nullptr },
+  { AV_CODEC_ID_MJPEG, "mjpeg", "jpeg_ni_quadra_enc", AV_PIX_FMT_YUVJ420P, AV_PIX_FMT_NI_QUAD, AV_HWDEVICE_TYPE_NI_QUADRA, "-1", nullptr },
 #endif
-  { AV_CODEC_ID_H265, "hevc", "hevc_vaapi", AV_PIX_FMT_NV12, AV_PIX_FMT_VAAPI, AV_HWDEVICE_TYPE_VAAPI, nullptr, nullptr },
+  { AV_CODEC_ID_H265, "hevc", "hevc_vaapi", AV_PIX_FMT_YUV420P, AV_PIX_FMT_VAAPI, AV_HWDEVICE_TYPE_VAAPI, nullptr, nullptr },
   { AV_CODEC_ID_H265, "hevc", "hevc_qsv", AV_PIX_FMT_YUV420P, AV_PIX_FMT_QSV, AV_HWDEVICE_TYPE_QSV, nullptr, nullptr },
-  { AV_CODEC_ID_H265, "hevc", "hevc_nvenc", AV_PIX_FMT_NV12, AV_PIX_FMT_NV12, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
+  { AV_CODEC_ID_H265, "hevc", "hevc_nvenc", AV_PIX_FMT_YUV420P, AV_PIX_FMT_NV12, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
   { AV_CODEC_ID_H265, "hevc", "libx265", AV_PIX_FMT_YUV420P, AV_PIX_FMT_YUV420P, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
 
-  { AV_CODEC_ID_H264, "h264", "h264_vaapi", AV_PIX_FMT_NV12, AV_PIX_FMT_VAAPI, AV_HWDEVICE_TYPE_VAAPI, nullptr, nullptr },
+  { AV_CODEC_ID_H264, "h264", "h264_vaapi", AV_PIX_FMT_YUV420P, AV_PIX_FMT_VAAPI, AV_HWDEVICE_TYPE_VAAPI, nullptr, nullptr },
   { AV_CODEC_ID_H264, "h264", "h264_qsv", AV_PIX_FMT_YUV420P, AV_PIX_FMT_QSV, AV_HWDEVICE_TYPE_QSV, nullptr, nullptr },
-  { AV_CODEC_ID_H264, "h264", "h264_nvenc", AV_PIX_FMT_NV12, AV_PIX_FMT_NV12, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
+  { AV_CODEC_ID_H264, "h264", "h264_nvenc", AV_PIX_FMT_YUV420P, AV_PIX_FMT_NV12, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
   { AV_CODEC_ID_H264, "h264", "h264_omx", AV_PIX_FMT_YUV420P, AV_PIX_FMT_YUV420P,  AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
   { AV_CODEC_ID_H264, "h264", "h264_v4l2m2m", AV_PIX_FMT_YUV420P, AV_PIX_FMT_YUV420P,  AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
   { AV_CODEC_ID_AV1, "av1", "av1_qsv", AV_PIX_FMT_YUV420P, AV_PIX_FMT_QSV, AV_HWDEVICE_TYPE_QSV, nullptr, nullptr },
@@ -258,13 +258,12 @@ int setup_hwaccel(
   codec_ctx->get_format = get_hw_format;
   codec_ctx->hw_device_ctx = av_buffer_ref(hw_device_ctx);
 
-if (1) {
   AVBufferRef *hw_frames_ref;
   AVHWFramesContext *frames_ctx = nullptr;
 
   if (!(hw_frames_ref = av_hwframe_ctx_alloc(hw_device_ctx))) {
     Error("Failed to create hwaccel frame context.");
-    return -1;;
+    return -1;
   }
   frames_ctx = (AVHWFramesContext *)(hw_frames_ref->data);
   frames_ctx->format    = codec_data->hw_pix_fmt;
@@ -284,10 +283,9 @@ if (1) {
     }
   }
   av_buffer_unref(&hw_frames_ref);
-}
   av_buffer_unref(&hw_device_ctx);
-  return 0;
 #endif
+  return 0;
 } // end setup_hwaccel
 
 
@@ -430,21 +428,29 @@ simple_round:
 }
 #endif
 
-static void zm_log_fps(double d, const char *postfix) {
+const std::string get_fps_string(double d, const char *postfix) {
   uint64_t v = lrintf(d * 100);
   if (!v) {
-    Debug(1, "%1.4f %s", d, postfix);
+    return stringtf("%1.4f %s", d, postfix);
   } else if (v % 100) {
-    Debug(1, "%3.2f %s", d, postfix);
+    return stringtf("%3.2f %s", d, postfix);
   } else if (v % (100 * 1000)) {
-    Debug(1, "%1.0f %s", d, postfix);
+    return stringtf("%1.0f %s", d, postfix);
   } else {
-    Debug(1, "%1.0fk %s", d / 1000, postfix);
+    return stringtf("%1.0fk %s", d / 1000, postfix);
   }
 }
 
+void zm_log_fps(double d, const char *postfix) {
+  Debug(1, "%s", get_fps_string(d, postfix).c_str());
+}
+
 void zm_dump_codecpar(const AVCodecParameters *par) {
-  Debug(1, "Dumping codecpar codec_type %d %s codec_id %d %s codec_tag %" PRIu32
+  Debug(1, "Dumping codecpar %s", get_codecpar_string(par).c_str());
+}
+
+const std::string get_codecpar_string(const AVCodecParameters *par) {
+  return stringtf("codec_type %d %s codec_id %d %s codec_tag %" PRIu32
         " width %d height %d bit_rate%" PRIu64 " bpcs %d bprs %d format%d %s"
         " extradata:%d:%s profile %d level %d field order %d color_range %d"
         " color_primaries %d color_trc %d color_space %d location %d video_delay %d",
@@ -523,18 +529,16 @@ void zm_dump_stream_format(AVFormatContext *ic, int i, int index, int is_output)
   if (flags & AVFMT_SHOW_IDS)
     Debug(1, "ids [0x%x]", st->id);
   Debug(1, "    Stream #%d:%d", index, i);
+  Debug(1, "global bitrate %" PRId64, ic->bit_rate);
   zm_dump_stream(st);
 }
-void zm_dump_stream(AVStream *st) {
-  AVDictionaryEntry *lang = av_dict_get(st->metadata, "language", nullptr, 0);
-  AVCodecParameters *codec = st->codecpar;
 
-  /* the pid is an important information, so we display it */
-  /* XXX: add a generic system */
-  if (lang)
-    Debug(1, "language (%s)", lang->value);
-  Debug(1, "frame_size:%d stream timebase: %d/%d", codec->frame_size, st->time_base.num, st->time_base.den);
-  Debug(1, "codec: %s %s", avcodec_get_name(st->codecpar->codec_id), av_get_media_type_string(st->codecpar->codec_type));
+void zm_dump_stream(AVStream *st) {
+  AVCodecParameters *codec = st->codecpar;
+  std::string output;
+
+  output += stringtf("frame_size:%d timebase: %d/%d", codec->frame_size, st->time_base.num, st->time_base.den);
+  output += stringtf(" codec: %s %s", avcodec_get_name(st->codecpar->codec_id), av_get_media_type_string(st->codecpar->codec_type));
 
   if (st->sample_aspect_ratio.num && // default
       av_cmp_q(st->sample_aspect_ratio, codec->sample_aspect_ratio)
@@ -545,11 +549,11 @@ void zm_dump_stream(AVStream *st) {
               codec->width  * (int64_t)st->sample_aspect_ratio.num,
               codec->height * (int64_t)st->sample_aspect_ratio.den,
               1024 * 1024);
-    Debug(1, ", SAR %d:%d DAR %d:%d",
+    output += stringtf(" SAR %d:%d DAR %d:%d",
           st->sample_aspect_ratio.num, st->sample_aspect_ratio.den,
           display_aspect_ratio.num, display_aspect_ratio.den);
   } else {
-    Debug(1, ", SAR %d:%d ",
+    output += stringtf(" SAR %d:%d ",
           st->sample_aspect_ratio.num, st->sample_aspect_ratio.den);
   }
 
@@ -558,45 +562,45 @@ void zm_dump_stream(AVStream *st) {
     int tbn = st->time_base.den && st->time_base.num;
 
     if (fps)
-      zm_log_fps(av_q2d(st->avg_frame_rate), "fps");
+      output += get_fps_string(av_q2d(st->avg_frame_rate), "fps");
     if (tbn)
-      zm_log_fps(1 / av_q2d(st->time_base), "stream tb numerator");
+      output += get_fps_string(1 / av_q2d(st->time_base), "stream tb numerator");
+
+    output += get_codecpar_string(codec);
   } else if (codec->codec_type == AVMEDIA_TYPE_AUDIO) {
 #if LIBAVUTIL_VERSION_CHECK(57, 28, 100, 28, 0)
-    Debug(1, "profile %d channels %d sample_rate %d",
+    output += stringtf("profile %d channels %d sample_rate %d",
           codec->profile, codec->ch_layout.nb_channels, codec->sample_rate);
 #else
-    Debug(1, "profile %d channels %d sample_rate %d",
+    output += stringtf("profile %d channels %d sample_rate %d",
           codec->profile, codec->channels, codec->sample_rate);
 #endif
   } else {
-    Debug(1, "Unknown codec type %d", codec->codec_type);
+    output += stringtf("Unknown codec type %d", codec->codec_type);
   }
 
   if (st->disposition & AV_DISPOSITION_DEFAULT)
-    Debug(1, " (default)");
+    output += " (default)";
   if (st->disposition & AV_DISPOSITION_DUB)
-    Debug(1, " (dub)");
+    output += " (dub)";
   if (st->disposition & AV_DISPOSITION_ORIGINAL)
-    Debug(1, " (original)");
+    output += " (original)";
   if (st->disposition & AV_DISPOSITION_COMMENT)
-    Debug(1, " (comment)");
+    output += " (comment)";
   if (st->disposition & AV_DISPOSITION_LYRICS)
-    Debug(1, " (lyrics)");
+    output += " (lyrics)";
   if (st->disposition & AV_DISPOSITION_KARAOKE)
-    Debug(1, " (karaoke)");
+    output += " (karaoke)";
   if (st->disposition & AV_DISPOSITION_FORCED)
-    Debug(1, " (forced)");
+    output += " (forced)";
   if (st->disposition & AV_DISPOSITION_HEARING_IMPAIRED)
-    Debug(1, " (hearing impaired)");
+    output += " (hearing impaired)";
   if (st->disposition & AV_DISPOSITION_VISUAL_IMPAIRED)
-    Debug(1, " (visual impaired)");
+    output += " (visual impaired)";
   if (st->disposition & AV_DISPOSITION_CLEAN_EFFECTS)
-    Debug(1, " (clean effects)");
+    output += " (clean effects)";
 
-  //dump_metadata(NULL, st->metadata, "    ");
-
-  //dump_sidedata(NULL, st, "    ");
+  Debug(1, "%s", output.c_str());
 }
 
 int check_sample_fmt(const AVCodec *codec, enum AVSampleFormat sample_fmt) {
@@ -794,3 +798,15 @@ int zm_get_samples_from_fifo(AVAudioFifo *fifo, AVFrame *frame) {
   zm_dump_frame(frame, "Out frame after fifo read");
   return 1;
 }
+#include <algorithm> // for std::max and std::min
+
+// Converts libjpeg quality [0-100] to ffmpeg -q:v [2-31] for MJPEG encoding
+int libjpeg_to_ffmpeg_qv(int libjpeg_quality) {
+    // Clamp libjpeg_quality to valid range
+    libjpeg_quality = std::max(0, std::min(100, libjpeg_quality));
+    // Map libjpeg 0-100 to ffmpeg 31-2
+    int ffmpeg_qv = 31 - static_cast<int>(libjpeg_quality * 29.0 / 100.0 + 0.5);
+    // Clamp ffmpeg_qv to valid range
+    ffmpeg_qv = std::max(2, std::min(31, ffmpeg_qv));
+    return ffmpeg_qv;
+}
