@@ -35,6 +35,10 @@ class Logger {
   private $logFile = '';
   private $logFd = NULL;
 
+  private $savedLogErrors = null;
+  private $savedErrorReporting = null;
+  private $savedDisplayErrors = null;
+
   public static $codes = array(
     self::DEBUG => 'DBG',
     self::INFO => 'INF',
@@ -63,7 +67,7 @@ class Logger {
 
   private function __construct() {
     $this->hasTerm = (php_sapi_name() == 'cli' && empty($_SERVER['REMOTE_ADDR']));
-    $this->logFile = $this->logPath.'/'.$this->id.'.log';
+    $this->logFile = $this->id.'.log';
   }
 
   public function __destruct() {
@@ -81,11 +85,11 @@ class Logger {
       $tempLogFile = $this->logPath.'/'.$this->id.'.log';
     }
     if ( isset($options['logFile']) )
-      $tempLogFile = $options['logFile'];
+      $tempLogFile = basename($options['logFile']);
     else
-      $tempLogFile = $this->logPath.'/'.$this->id.'.log';
+      $tempLogFile = $this->id.'.log';
     if ( !is_null($logFile = $this->getTargettedEnv('LOG_FILE')) )
-      $tempLogFile = $logFile;
+      $tempLogFile = basename($logFile);
 
     $tempLevel = self::INFO;
     $tempTermLevel = $this->termLevel;
@@ -139,7 +143,7 @@ class Logger {
           if ( ZM_LOG_DEBUG_LEVEL > self::NOLOG ) {
             $tempLevel = $this->limit( ZM_LOG_DEBUG_LEVEL );
             if ( ZM_LOG_DEBUG_FILE != '' ) {
-              $tempLogFile = ZM_LOG_DEBUG_FILE;
+              $tempLogFile = basename(ZM_LOG_DEBUG_FILE);
               $tempFileLevel = $tempLevel;
             }
           }
@@ -237,8 +241,8 @@ class Logger {
         $this->effectiveLevel = $this->level;
       if ( !$this->hasTerm ) {
         if ( $lastLevel < self::DEBUG && $this->level >= self::DEBUG ) {
-          $this->savedErrorReporting = error_reporting(E_ALL & ~E_NOTICE & ~E_DEPRECATED);
-          $this->savedDisplayErrors = ini_set('display_errors', true);
+          $this->savedErrorReporting = error_reporting(E_ALL);
+          $this->savedDisplayErrors = ini_set('display_errors', false);
         } elseif ( $lastLevel >= self::DEBUG && $this->level < self::DEBUG ) {
           error_reporting($this->savedErrorReporting);
           ini_set('display_errors', $this->savedDisplayErrors);
@@ -338,7 +342,7 @@ class Logger {
 
   private function openFile() {
     if ( !$this->useErrorLog ) {
-      if ( $this->logFd = fopen($this->logFile, 'a+') ) {
+      if ( $this->logFd = fopen($this->logPath.'/'.$this->logFile, 'a+') ) {
         if ( strnatcmp(phpversion(), '5.2.0') >= 0 ) {
           $error = error_get_last();
           trigger_error("Can't open log file '$logFile': ".$error['message'].' @ '.$error['file'].'/'.$error['line'], E_USER_ERROR);
@@ -359,13 +363,14 @@ class Logger {
     }
 
     $string = preg_replace('/[\r\n]+$/', '', $string);
+    $string = substr($string, 0, 65535); # Message Column has max length
     $code = self::$codes[$level];
 
     global $dateTimeFormatter;
     $time = gettimeofday();
     $message = sprintf('%s.%06d %s[%d].%s [%s] [%s]',
       $dateTimeFormatter->format($time['sec']), $time['usec'],
-      $this->id, getmypid(), $code, $_SERVER['REMOTE_ADDR'], $string);
+      $this->id, getmypid(), $code, (!empty($_SERVER['HTTP_X_FORWARDED_FOR']) ? $_SERVER['HTTP_X_FORWARDED_FOR'] : $_SERVER['REMOTE_ADDR']), $string);
 
     if ( is_null($file) ) {
       if ( $this->useErrorLog || ($this->databaseLevel > self::NOLOG) ) {
@@ -395,7 +400,7 @@ class Logger {
 
     if ( $level <= $this->fileLevel ) {
       if ( $this->useErrorLog ) {
-        if ( !error_log($message."\n", 3, $this->logFile) ) {
+        if ( !error_log($message."\n", 3, $this->logPath.'/'.$this->logFile) ) {
           if ( strnatcmp(phpversion(), '5.2.0') >= 0 ) {
             $error = error_get_last();
             $this->fileLevel = self::NOLOG;
