@@ -27,7 +27,7 @@ monitorData[monitorData.length] = {
   'width': <?php echo $monitor->ViewWidth() ?>,
   'height':<?php echo $monitor->ViewHeight() ?>,
   'RTSP2WebEnabled':<?php echo $monitor->RTSP2WebEnabled() ?>,
-  'RTSP2WebType':'<?php echo $monitor->RTSP2WebType() ?>',
+  'DefaultPlayer':'<?php echo $monitor->DefaultPlayer() ?>',
   'RTSP2WebStream':'<?php echo $monitor->RTSP2WebStream() ?>',
   'Go2RTCEnabled': <?php echo $monitor->Go2RTCEnabled() ?>,
   'janusEnabled':<?php echo $monitor->JanusEnabled() ?>,
